#!/bin/bash

#CONFIG FILE FOR PI/global mean scripts
#Paolo Davini (ISAC-CNR) - <p.davini@isac.cnr.it>
#December 2014

#Adapted for IC3 by François Massonnet (UCL/IC3) <francois.massonnet@ic3.cat>
#January 2015

#Adapted for BSC by François Massonnet (UCL/BSC) <francois.massonnet@uclouvain.be>
#November 2017

set -o nounset
set -o errexit

module load CDO/1.8.2-foss-2019b
module load NCO

# START TO EDIT HERE

# Where the program is placed
MAINDIR=/esarchive/scratch/bsc32627/git/repro/scripts/


# Start date of the run (YYYYMMDD)
STARTDATE=19500101

# EC-Earth version [3.1 or later]
ECVERSION=3.3.3.2

# Directory where the outputs are located. In this directory one should find the 
# MMO, MMA, tar files and the ICMGG, ICMSH grib files of each year 
DATADIR=/esarchive/exp/ecearth/${exp}/original_files/$STARTDATE/

# (Scratch) directory where the processed output can be saved before the climate diagnostics are run
SAVEDIR=/esarchive/scratch/bsc32627/repro_tests/${exp}/${STARTDATE}

# Scratch dir where to run the analyses
SCRADIR=/esarchive/scratch/bsc32627/repro_tests/TMP

# Time frequency of atmosphere output. 
# If you use autosubmit, can be retrieved from expdef_${exp}.conf, variable NFRP
NFRP=6

# Functions used during the scripts
# Required programs, including compression options
cdo="/gpfs/projects/bsc32/software/suselinux/11/software/CDO/1.8.2-foss-2019b/bin/cdo"
cdozip="$cdo -f nc4c -z zip"
cdonc="$cdo -f nc"

#preferred type of CDO interpolation (curvilinear grids are obliged to use bilinear)
remap="remapcon2"

#T255 masks (or theoretically different resolution) are used by ./global_mean.sh 
#and by ./post2x2.sh scripts. They are computed from the original initial conditions of IFS (using var 172)
#maskfile=/home/hpc/pr45de/di56bov/work/ecearth3/setup/ifs/T255L91/19900101/ICMGGECE3INIT
ece3_constant_files=/esarchive/releases/models/ecearth/ece3_constant
maskfile=${ece3_constant_files}/ifs/T255L91/ICMGGECE3INIT

#Copy Climate_netcdf files
cp -r ${ece3_constant_files}/Climate_netcdf ${MAINDIR}

# Where Reichler and Kim indices will be saved
OUTDIR=${MAINDIR}/EC-Earth_diags/${exp}/
# Where model climatologies will be saved
CLIMDIR=${MAINDIR}/EC-Earth_diags/${exp}/
